<?php
 /**
  * @package WPBlink_Flatolio
  * @since 1.0
  * @modified  1.0
 */
 
class My_Theme_Options {
	
	private $sections;
	private $checkboxes;
	private $settings;
	
	/**
	 * Construct
	 *
	 * @since 1.0
	 */
	public function __construct() {
		
		// This will keep track of the checkbox options for the validate_settings function.
		$this->checkboxes = array();
		$this->settings = array();
		$this->get_option();
		
		$this->sections['slider']   = __( 'Slider', 'wpblink_flatolio' );
		$this->sections['features']   = __( 'Features', 'wpblink_flatolio' );
		$this->sections['demo']   = __( 'Demo', 'wpblink_flatolio' );
		$this->sections['static']   = __( 'Static', 'wpblink_flatolio' );
		$this->sections['support']   = __( 'Support', 'wpblink_flatolio' );
		$this->sections['buynow']   = __( 'Buy Now', 'wpblink_flatolio' );
		$this->sections['miscellaneous']   = __( 'Misc', 'wpblink_flatolio' );
		
		add_action( 'admin_menu', array( &$this, 'add_pages' ) );
		add_action( 'admin_init', array( &$this, 'register_settings' ) );
		
		if ( ! get_option( 'mytheme_options' ) )
			$this->initialize_settings();
		
	}
	
	/**
	 * Add options page
	 *
	 * @since 1.0
	 */
	public function add_pages() {
		
		$admin_page = add_theme_page( __( 'Theme Options', 'wpblink_flatolio' ), __( 'Theme Options', 'wpblink_flatolio' ), 'manage_options', 'mytheme-options', array( &$this, 'display_page' ) );
		
		add_action( 'admin_print_scripts-' . $admin_page, array( &$this, 'scripts' ) );
		add_action( 'admin_print_styles-' . $admin_page, array( &$this, 'styles' ) );
		
	}
	
	/**
	 * Create settings field
	 *
	 * @since 1.0
	 */
	public function create_setting( $args = array() ) {
		
		$defaults = array(
			'id'      => 'default_field',
			'title'   => __( 'Default Field', 'wpblink_flatolio' ),
			'desc'    => __( 'This is a default description.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'general',
			'choices' => array(),
			'class'   => ''
		);
			
		extract( wp_parse_args( $args, $defaults ) );
		
		$field_args = array(
			'type'      => $type,
			'id'        => $id,
			'desc'      => $desc,
			'std'       => $std,
			'choices'   => $choices,
			'label_for' => $id,
			'class'     => $class
		);
		
		if ( $type == 'checkbox' )
			$this->checkboxes[] = $id;
		
		add_settings_field( $id, $title, array( $this, 'display_setting' ), 'mytheme-options', $section, $field_args );
	}
	
	/**
	 * Display options page
	 *
	 * @since 1.0
	 */
	public function display_page() {
		
		echo '<div class="wrap">';
	
		if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true )
			echo '<div class="updated fade"><p>' . __( 'Theme options updated.', 'wpblink_flatolio' ) . '</p></div>';
		
		echo '<form action="options.php" method="post">';
	
		settings_fields( 'mytheme_options' );
		echo '<div class="ui-tabs">
		
		<h2 class="options_title">' . __( 'Theme Options', 'wpblink_flatolio' ) . '</h2>
		
			<ul class="ui-tabs-nav">';
		
		foreach ( $this->sections as $section_slug => $section )
			echo '<li><a href="#' . $section_slug . '">' . $section . '</a></li>';
		
		echo '</ul>';
		do_settings_sections( $_GET['page'] );
		
		echo '</div>
		<p class="submit"><input name="Submit" type="submit" class="button-primary" value="' . __( 'Save Changes', 'wpblink_flatolio' ) . '" /></p>
		
	</form>';
	
	echo '<script type="text/javascript">
		jQuery(document).ready(function($) {
			var sections = [];';
			
			foreach ( $this->sections as $section_slug => $section )
				echo "sections['$section'] = '$section_slug';";
			
			echo 'var wrapped = $(".wrap h3").wrap("<div class=\"ui-tabs-panel\">");
			wrapped.each(function() {
				$(this).parent().append($(this).parent().nextUntil("div.ui-tabs-panel"));
			});
			$(".ui-tabs-panel").each(function(index) {
				$(this).attr("id", sections[$(this).children("h3").text()]);
				if (index > 0)
					$(this).addClass("ui-tabs-hide");
			});
			$(".ui-tabs").tabs({
				fx: { opacity: "toggle", duration: "fast" }
			});
			
			$("input[type=text], textarea").each(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "")
					$(this).css("color", "#999");
			});
			
			$("input[type=text], textarea").focus(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "") {
					$(this).val("");
					$(this).css("color", "#000");
				}
			}).blur(function() {
				if ($(this).val() == "" || $(this).val() == $(this).attr("placeholder")) {
					$(this).val($(this).attr("placeholder"));
					$(this).css("color", "#999");
				}
			});
			
			$(".wrap h3, .wrap table").show();
			
			// This will make the "warning" checkbox class really stand out when checked.
			// I use it here for the Reset checkbox.
			$(".warning").change(function() {
				if ($(this).is(":checked"))
					$(this).parent().css("background", "#e74c3c").css("color", "#fff").css("fontWeight", "bold");
				else
					$(this).parent().css("background", "none").css("color", "inherit").css("fontWeight", "normal");
			});
			
			// Browser compatibility
			if ($.browser.mozilla) 
			         $("form").attr("autocomplete", "off");
		});
	</script>
</div>';
		
	}
	
	/**
	 * Description for section
	 *
	 * @since 1.0
	 */
	public function display_section() {
		// code
	}
	
	/**
	 * Description for About section
	 *
	 * @since 1.0
	 */
	public function display_about_section() {
		
		// This displays on the "About" tab. Echo regular HTML here, like so:
		// echo '<p>Copyright 2014 me@example.com</p>';
		
	}
	
	/**
	 * HTML output for text field
	 *
	 * @since 1.0
	 */
	public function display_setting( $args = array() ) {
		
		extract( $args );
		
		$options = get_option( 'mytheme_options' );
		
		if ( ! isset( $options[$id] ) && $type != 'checkbox' )
			$options[$id] = $std;
		elseif ( ! isset( $options[$id] ) )
			$options[$id] = 0;
		
		$field_class = '';
		if ( $class != '' )
			$field_class = ' ' . $class;
		
		switch ( $type ) {
			
			case 'heading':
				echo '</td></tr><tr valign="top"><td colspan="2"><h4>' . $desc . '</h4>';
				break;
			
			case 'checkbox':
				
				echo '<input class="checkbox' . $field_class . '" type="checkbox" id="' . $id . '" name="mytheme_options[' . $id . ']" value="1" ' . checked( $options[$id], 1, false ) . ' /> <label for="' . $id . '">' . $desc . '</label>';
				
				break;
			
			case 'select':
				echo '<select class="select' . $field_class . '" name="mytheme_options[' . $id . ']">';
				
				foreach ( $choices as $value => $label )
					echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';
				
				echo '</select>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'radio':
				$i = 0;
				foreach ( $choices as $value => $label ) {
					echo '<input class="radio' . $field_class . '" type="radio" name="mytheme_options[' . $id . ']" id="' . $id . $i . '" value="' . esc_attr( $value ) . '" ' . checked( $options[$id], $value, false ) . '> <label for="' . $id . $i . '">' . $label . '</label>';
					if ( $i < count( $options ) - 1 )
						echo '<br />';
					$i++;
				}
				
				if ( $desc != '' )
					echo '<span class="description">' . $desc . '</span>';
				
				break;
			
			case 'textarea':
				echo '<textarea class="' . $field_class . '" id="' . $id . '" name="mytheme_options[' . $id . ']" placeholder="' . $std . '" rows="5" cols="30">' . wp_htmledit_pre( $options[$id] ) . '</textarea>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'password':
				echo '<input class="regular-text' . $field_class . '" type="password" id="' . $id . '" name="mytheme_options[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" />';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'text':
			default:
		 		echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="mytheme_options[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 		
		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';
		 		
		 		break;
		 	
		}
		
	}
	
	/**
	 * Settings and defaults
	 * 
	 * @since 1.0
	 */
	public function get_option() {
		

		/* Slider
		===========================================*/

		$this->settings['title_slider_style'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Style',
			'type'    => 'heading'
		);

		$this->settings['cp_slider_bg'] = array(
			'section' => 'slider',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '18bca1',
		);
		
		$this->settings['cp_slider_button'] = array(
			'section' => 'slider',
			'title' => __( 'Button Hover', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a hover color for the slider buttons (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => 'd64b2a',
		);
					
		$this->settings['title_slide1'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Slide #1',
			'type'    => 'heading'
		);
		

		$this->settings['slider_1_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		$this->settings['slider_1_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'slider'
		);
		
		$this->settings['slider_1_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (980*473px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		
		
		$this->settings['title_slide2'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Slide #2',
			'type'    => 'heading'
		);
		

		$this->settings['slider_2_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		$this->settings['slider_2_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'slider'
		);
		
		$this->settings['slider_2_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (980*473px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		
		
		
		$this->settings['title_slide3'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Slide #3',
			'type'    => 'heading'
		);
		

		$this->settings['slider_3_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		$this->settings['slider_3_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'slider'
		);
		
		$this->settings['slider_3_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (980*473px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		
		
		
		$this->settings['title_slide4'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Slide #4',
			'type'    => 'heading'
		);
		

		$this->settings['slider_4_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		$this->settings['slider_4_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'slider'
		);
		
		$this->settings['slider_4_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (980*473px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		
		
		
		$this->settings['title_slide5'] = array(
			'section' => 'slider',
			'title'   => '', // Not used for headings.
			'desc'    => 'Slide #5',
			'type'    => 'heading'
		);
		

		$this->settings['slider_5_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		$this->settings['slider_5_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text for this slide.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'slider'
		);
		
		$this->settings['slider_5_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (980*473px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'slider'
		);
		
		
		


		
		
		
		
		/* Features
		===========================================*/

		$this->settings['title_features_style'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Style',
			'type'    => 'heading'
		);
		

		$this->settings['cp_features_bg'] = array(
			'section' => 'features',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '3b83f9',
		);
		
		$this->settings['title_features_general'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'General',
			'type'    => 'heading'
		);
		
		$this->settings['features_menu'] = array(
			'title'   => __( 'Menu Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom menu name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_anchor'] = array(
			'title'   => __( 'Anchor Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom anchor name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);
		
		$this->settings['title_spotlight_1'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Spotlight #1',
			'type'    => 'heading'
		);
		

		$this->settings['spotlight_1_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this spotlight.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['spotlight_1_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (475*404px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['title_spotlight_2'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Spotlight #2',
			'type'    => 'heading'
		);
		
		$this->settings['spotlight_2_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this spotlight.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['spotlight_2_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (475*404px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['title_spotlight_3'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Spotlight #3',
			'type'    => 'heading'
		);
		
		$this->settings['spotlight_3_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this spotlight.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['spotlight_3_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (475*404px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
			
		$this->settings['title_features'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature List',
			'type'    => 'heading'
		);
		

		$this->settings['features_header'] = array(
			'title'   => __( 'Heading', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom heading text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_subtxt'] = array(
			'title'   => __( 'Sub-Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom sub-text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
	
		$this->settings['features_1'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #1',
			'type'    => 'heading'
		);
		

		$this->settings['features_1_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_1_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_2'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #2',
			'type'    => 'heading'
		);
		

		$this->settings['features_2_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_2_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_3'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #3',
			'type'    => 'heading'
		);
		
		$this->settings['features_3_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_3_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_4'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #4',
			'type'    => 'heading'
		);
		
		$this->settings['features_4_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_4_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_5'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #5',
			'type'    => 'heading'
		);
		
		$this->settings['features_5_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_5_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_6'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #6',
			'type'    => 'heading'
		);
		
		$this->settings['features_6_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_6_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_7'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #7',
			'type'    => 'heading'
		);
		
		$this->settings['features_7_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_7_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_8'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #8',
			'type'    => 'heading'
		);
		
		$this->settings['features_8_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_8_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_9'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #9',
			'type'    => 'heading'
		);
		
		$this->settings['features_9_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_9_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_10'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #10',
			'type'    => 'heading'
		);
		
		$this->settings['features_10_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_10_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_11'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #11',
			'type'    => 'heading'
		);
		

		$this->settings['features_11_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_11_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_12'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #12',
			'type'    => 'heading'
		);
		

		$this->settings['features_12_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_12_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_13'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #13',
			'type'    => 'heading'
		);
		
		$this->settings['features_13_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_13_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_14'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #14',
			'type'    => 'heading'
		);
		
		$this->settings['features_14_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_14_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_15'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #15',
			'type'    => 'heading'
		);
		
		$this->settings['features_15_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_15_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_16'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #16',
			'type'    => 'heading'
		);
		
		$this->settings['features_16_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_16_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_17'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #17',
			'type'    => 'heading'
		);
		
		$this->settings['features_17_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_17_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_18'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #18',
			'type'    => 'heading'
		);
		
		$this->settings['features_18_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_18_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_19'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #19',
			'type'    => 'heading'
		);
		
		$this->settings['features_19_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_19_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_20'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #20',
			'type'    => 'heading'
		);
		
		$this->settings['features_20_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_20_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_21'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #21',
			'type'    => 'heading'
		);
		

		$this->settings['features_21_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_21_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_22'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #22',
			'type'    => 'heading'
		);
		

		$this->settings['features_22_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_22_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_23'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #23',
			'type'    => 'heading'
		);
		
		$this->settings['features_23_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_23_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_24'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #24',
			'type'    => 'heading'
		);
		
		$this->settings['features_24_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_24_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_25'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #25',
			'type'    => 'heading'
		);
		
		$this->settings['features_25_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_25_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_26'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #26',
			'type'    => 'heading'
		);
		
		$this->settings['features_26_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_26_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_27'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #27',
			'type'    => 'heading'
		);
		
		$this->settings['features_27_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_27_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_28'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #28',
			'type'    => 'heading'
		);
		
		$this->settings['features_28_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_28_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_29'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #29',
			'type'    => 'heading'
		);
		
		$this->settings['features_29_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_29_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_30'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #30',
			'type'    => 'heading'
		);
		
		$this->settings['features_30_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_30_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_31'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #31',
			'type'    => 'heading'
		);
		
		$this->settings['features_31_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_31_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_32'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #32',
			'type'    => 'heading'
		);
		
		$this->settings['features_32_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_32_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);
		
		$this->settings['features_33'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #33',
			'type'    => 'heading'
		);
		
		$this->settings['features_33_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_33_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_34'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #34',
			'type'    => 'heading'
		);
		
		$this->settings['features_34_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_34_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		
		$this->settings['features_35'] = array(
			'section' => 'features',
			'title'   => '', // Not used for headings.
			'desc'    => 'Feature #35',
			'type'    => 'heading'
		);
		
		$this->settings['features_35_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'features'
		);	
		
		$this->settings['features_35_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom content text for this feature.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'features'
		);	
		

		

		
		/* Demo
		===========================================*/


		$this->settings['title_demo_style'] = array(
			'section' => 'demo',
			'title'   => '', // Not used for headings.
			'desc'    => 'Style',
			'type'    => 'heading'
		);

		$this->settings['cp_demo_bg'] = array(
			'section' => 'demo',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => 'd64b2a',
		);
		
			
		$this->settings['title_demo'] = array(
			'section' => 'demo',
			'title'   => '', // Not used for headings.
			'desc'    => 'Demonstration',
			'type'    => 'heading'
		);
		

		$this->settings['demo_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_menu'] = array(
			'title'   => __( 'Menu Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom menu name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_anchor'] = array(
			'title'   => __( 'Anchor Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom anchor name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'demo'
		);	
		
		$this->settings['demo_img_1'] = array(
			'title'   => __( 'Image #1', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_url_1'] = array(
			'title'   => __( 'URL #1', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full destination URL.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
	
		
		$this->settings['demo_img_2'] = array(
			'title'   => __( 'Image #2', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_url_2'] = array(
			'title'   => __( 'URL #2', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full destination URL.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		

		
		$this->settings['demo_img_3'] = array(
			'title'   => __( 'Image #3', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_url_3'] = array(
			'title'   => __( 'URL #3', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full destination URL.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		
		
		$this->settings['demo_img_4'] = array(
			'title'   => __( 'Image #4', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);	
		
		$this->settings['demo_url_4'] = array(
			'title'   => __( 'URL #4', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full destination URL.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'demo'
		);
		

		

		
		$this->settings['demo_subtxt'] = array(
			'title'   => __( 'Sub-text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom sub-text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'demo'
		);	
		
		
		
		
		/* Static
		===========================================*/

	
		$this->settings['title_static_a'] = array(
			'section' => 'static',
			'title'   => '', // Not used for headings.
			'desc'    => 'Static A',
			'type'    => 'heading'
		);
		
		$this->settings['cp_static_a_bg'] = array(
			'section' => 'static',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '3b83f9',
		);
		

		$this->settings['static_a_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['static_a_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'static'
		);	
		
		$this->settings['static_a_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['title_static_b'] = array(
			'section' => 'static',
			'title'   => '', // Not used for headings.
			'desc'    => 'Static B',
			'type'    => 'heading'
		);
		
		$this->settings['cp_static_b_bg'] = array(
			'section' => 'static',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => 'be153e',
		);
		
		$this->settings['static_b_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['static_b_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'static'
		);	
		
		$this->settings['static_b_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['title_static_c'] = array(
			'section' => 'static',
			'title'   => '', // Not used for headings.
			'desc'    => 'Static C',
			'type'    => 'heading'
		);
		
		$this->settings['cp_static_c_bg'] = array(
			'section' => 'static',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '3b83f9',
		);
		
		$this->settings['static_c_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['static_c_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'static'
		);	
		
		$this->settings['static_c_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['title_static_d'] = array(
			'section' => 'static',
			'title'   => '', // Not used for headings.
			'desc'    => 'Static D',
			'type'    => 'heading'
		);
		
		$this->settings['cp_static_d_bg'] = array(
			'section' => 'static',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => 'd64b2a',
		);
		
		$this->settings['static_d_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		$this->settings['static_d_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'static'
		);	
		
		$this->settings['static_d_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen image (450*256px).', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'static'
		);
		
		
		
		
		/* Support
		===========================================*/


		$this->settings['title_support_style'] = array(
			'section' => 'support',
			'title'   => '', // Not used for headings.
			'desc'    => 'Style',
			'type'    => 'heading'
		);

		$this->settings['cp_support_bg'] = array(
			'section' => 'support',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '3b83f9',
		);
		
		$this->settings['cp_cf'] = array(
			'section' => 'support',
			'title' => __( 'Submit Button', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for the contact form submit button (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => 'e67e22',
		);
			
		$this->settings['title_support'] = array(
			'section' => 'support',
			'title'   => '', // Not used for headings.
			'desc'    => 'Support',
			'type'    => 'heading'
		);
		

		$this->settings['support_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'support'
		);	
		
		$this->settings['support_menu'] = array(
			'title'   => __( 'Menu Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom menu name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'support'
		);	
		
		$this->settings['support_anchor'] = array(
			'title'   => __( 'Anchor Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom anchor name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'support'
		);	
		
		$this->settings['support_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'support'
		);	
		
		$this->settings['support_img'] = array(
			'title'   => __( 'Image URL', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen support image.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'support'
		);
		
		$this->settings['support_form'] = array(
			'title'   => __( 'Form', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your Contact Form 7 shortcode.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'support'
		);	

		

		/* Buy Now
		===========================================*/

	
		$this->settings['title_buynow'] = array(
			'section' => 'buynow',
			'title'   => '', // Not used for headings.
			'desc'    => 'Buy Now',
			'type'    => 'heading'
		);
		
		$this->settings['cp_buynow_bg'] = array(
			'section' => 'buynow',
			'title' => __( 'Background', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a background color for this section (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '18bca1',
		);
		

		$this->settings['buynow_title'] = array(
			'title'   => __( 'Title', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom title text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);	
		
		$this->settings['buynow_menu'] = array(
			'title'   => __( 'Menu Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom menu name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);	
		
		$this->settings['buynow_anchor'] = array(
			'title'   => __( 'Anchor Name', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom anchor name.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);	
		
		$this->settings['buynow_txt'] = array(
			'title'   => __( 'Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'buynow'
		);
		
		$this->settings['buynow_img'] = array(
			'title'   => __( 'Image', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen Buy Now image.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);
		
		$this->settings['buynow_url'] = array(
			'title'   => __( 'URL', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen destination.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);	
		
		$this->settings['buynow_cart'] = array(
			'title'   => __( 'Cart URL', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL to your chosen cart.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'buynow'
		);	
		
		$this->settings['buynow_subtxt'] = array(
			'title'   => __( 'Sub-Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter your custom sub-text.', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'buynow'
		);
		
				
		/* Miscellaneous Settings
		===========================================*/
	
		$this->settings['title_miscellaneous_style'] = array(
			'section' => 'miscellaneous',
			'title'   => '', // Not used for headings.
			'desc'    => 'Style',
			'type'    => 'heading'
		);

		$this->settings['cp_menu'] = array(
			'section' => 'miscellaneous',
			'title' => __( 'Menu', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a color for the menu buttons (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '3b83f9',
		);
		
		$this->settings['cp_menu_hover'] = array(
			'section' => 'miscellaneous',
			'title' => __( 'Menu Hover', 'wpblink_flexpost' ),
			'desc' => __( 'Choose a hover color for the menu buttons (leave blank for default value).', 'wpblink_flexpost' ),
			'class' => "color {pickerMode:'HVS',pickerFaceColor:'#333333',pickerBorder: 0}", // Custom class for CSS
			'type' => 'text',
			'std' => '21aeb0',
		);
		
		
		$this->settings['title_social'] = array(
			'section' => 'miscellaneous',
			'title'   => '', // Not used for headings.
			'desc'    => 'Social',
			'type'    => 'heading'
		);
		
		$this->settings['misc_twitter'] = array(
			'title'   => __( 'Twitter', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL of your Twitter page', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'miscellaneous'
		);
		
		$this->settings['misc_facebook'] = array(
			'title'   => __( 'Facebook', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL of your Facebook page', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'miscellaneous'
		);		
				
		$this->settings['title_copyright'] = array(
			'section' => 'miscellaneous',
			'title'   => '', // Not used for headings.
			'desc'    => 'Copyright',
			'type'    => 'heading'
		);
		
		$this->settings['misc_copyright'] = array(
			'title'   => __( 'Copyright Text', 'wpblink_flatolio' ),
			'desc'    => __( 'Enter the full URL of your Twitter page', 'wpblink_flatolio' ),
			'std'     => '',
			'type'    => 'textarea',
			'section' => 'miscellaneous'
		);

		
	}
	
	/**
	 * Initialize settings to their default values
	 * 
	 * @since 1.0
	 */
	public function initialize_settings() {
		
		$default_settings = array();
		foreach ( $this->settings as $id => $setting ) {
			if ( $setting['type'] != 'heading' )
				$default_settings[$id] = $setting['std'];
		}
		
		update_option( 'mytheme_options', $default_settings );
		
	}
	
	/**
	* Register settings
	*
	* @since 1.0
	*/
	public function register_settings() {
		
		register_setting( 'mytheme_options', 'mytheme_options', array ( &$this, 'validate_settings' ) );
		
		foreach ( $this->sections as $slug => $title ) {
			if ( $slug == 'about' )
				add_settings_section( $slug, $title, array( &$this, 'display_about_section' ), 'mytheme-options' );
			else
				add_settings_section( $slug, $title, array( &$this, 'display_section' ), 'mytheme-options' );
		}
		
		$this->get_option();
		
		foreach ( $this->settings as $id => $setting ) {
			$setting['id'] = $id;
			$this->create_setting( $setting );
		}
		
	}
	
	/**
	* jQuery Tabs
	*
	* @since 1.0
	*/
	public function scripts() {
		
		wp_print_scripts( 'jquery-ui-tabs' );
		
	}
	
	/**
	* Styling for the theme options page
	*
	* @since 1.0
	*/
	public function styles() {
		
		wp_register_style( 'mytheme-admin', get_template_directory_uri() . '/options/options.css' );
		wp_enqueue_style( 'mytheme-admin' );
		
	}
	
	/**
	* Validate settings
	*
	* @since 1.0
	*/
	public function validate_settings( $input ) {
		
		if ( ! isset( $input['reset_theme'] ) ) {
			$options = get_option( 'mytheme_options' );
			
			foreach ( $this->checkboxes as $id ) {
				if ( isset( $options[$id] ) && ! isset( $input[$id] ) )
					unset( $options[$id] );
			}
			
			return $input;
		}
		return false;
		
	}
	
}

$theme_options = new My_Theme_Options();

function mytheme_option( $option ) {
	$options = get_option( 'mytheme_options' );
	if ( isset( $options[$option] ) )
		return $options[$option];
	else
		return false;
}
?>